/*
  Library support for FlexRadio 6000 Rigs
  Copyright (C)2015 Vincenzo Stefanazzi - IW7DMH. All right reserved

  This library is free software; you can redistribute it and/or
  modify it under the terms of the CC BY-NC-SA 3.0 license.
  https://creativecommons.org/licenses/by-nc-sa/3.0/
  
  The license applies to all part of the library including the 
  examples and tools supplied with the library.
*/
#ifndef Slice_h
#define Slice_h
#include "Arduino.h"

#define SLICE_AUDIO_GAIN 6000
#define SLICE_AUDIO_PAN 6001
#define SLICE_AGC_THRESHOLD 6003
#define SLICE_NB_LEVEL 6004
#define SLICE_NR_LEVEL 6005
#define SLICE_APF_LEVEL 6006
#define SLICE_RIT_FREQ 6007
#define SLICE_XIT_FREQ 6008
#define SLICE_FILTER_LOW 6009
#define SLICE_FILTER_HIGH 6010
#define SLICE_FILTER_SHIFT 6011
#define SLICE_FILTER_WIDTH 6012
#define SLICE_AGC_OFF_LEVEL 6013				 
#define SLICE_ANF_LEVEL 6014

enum SLICE_MODES {LSB=0,USB,AM,CW,DIGL,DIGU,FM,NFM,DFM,SAM_};

class Slice
{
  public:
    //properties
	int in_use; //=1 
	int RF_frequency; //=14.036600 
	int rit_on; //=0 
	int rit_freq; //=0 
	int xit_on; //=0 
	int xit_freq; //=0 
	String rxant; //=ANT1 
	String mode; //=CW 
	int wide; //=0 
	int filter_lo; //=-200
	int filter_hi; //=200
	int step; //=10 
	String step_list; //=1,5,10,50,100,200,400
	String agc_mode; //=med 
	int agc_threshold; //=65 
	int agc_off_level; //=10 
	int pan; //=0x40000000 
	String txant; //=ANT1 
	int loopa; //=0 
	int loopb; //=0 
	int qsk; //=1 
	int dax; //=1 
	int dax_clients; //=0 
	int lock; //=0 
	int tx; //=1 
	int dax_tx; //=0 
	int active; //=0 
	int audio_gain; //=50 
	int audio_pan; //=50 
	int audio_mute; //=0 
	int record; //=0 
	String play; //=disabled 
	int record_time; //=0.0 
	int anf; //=0 
	int anf_level; //=0 
	int nr; //=0 
	int nr_level; //=50 
	int nb; //=0 
	int nb_level; //=50 
	int apf; //=0 
	int apf_level; //=7 
	int diversity; //=0 
	int diversity_parent; //=0 
	int diversity_child; //=0 
	int diversity_index; //=1342177293 
	String ant_list; //=ANT1,ANT2,XVTR
	
	int intMode; //Numeric value that identifies one of the SLICE_MODES
	int oldIntMode;
    boolean updated;
	int filter_shift;
	int filter_width; 

    //methods
    Slice();
	void updateStatus(String msg);
	void updateObject(int objectId,int value);  //Update specific slice object	
	void setFilterLow(int value);
    void setFilterHigh(int value);
    void setFilterShift(int value);
	void setFilterWidth(int value);
	int getBand();

  private:
    //properties
	
	
    //methods	
	void setValue(String msg);
	void setIntMode(String m);
	void calcHighLowValues();
	void calcShiftWidthValue();
	
};
	
#endif